@@ -7,6 +7,10 @@ function (object, locations = coordinates(data), data, ...)
 	# both data and coordinates --- see there.
 	## ret = gstat.formula(object, locations, data)
 	## variogram(object = ret$y, locations = ret$locations, X = ret$X, ...)
-	g = gstat(formula = object, locations = locations, data = data)
-	variogram(g, ...)
+	if ((missing(locations) && is(data, "ST")) || (is(locations, "ST")))
+		variogramST(formula = object, locations = locations, data = data, ...)
+	else {
+		g = gstat(formula = object, locations = locations, data = data)
+		variogram(g, ...)
+	}
 }
