@@ -1,6 +1,4 @@
-#include "config.h"
-
-# include <math.h>
+#include <math.h> /* sin() etc */
 
 #include <R.h>
 #include <Rmath.h>
@@ -33,10 +31,6 @@ double gstat_gcdist(double lon1, double lon2, double lat1, double lat2) {
     G = (lat1R - lat2R) / 2.0;
     L = (lon1R - lon2R) / 2.0;
 
-	/*
-    printf("%g %g %g %g; %g %g %g\n",  *lon1, *lon2, *lat1, *lat2, F, G, L);
-	*/
-
     sinG2 = POWDI(sin(G), 2);
     cosG2 = POWDI(cos(G), 2);
     sinF2 = POWDI(sin(F), 2);
